Room class

Rectangular room

Constructors

Room(Rect bounds)
const

Properties

aspectRatio → double
no setter
bounds → Rect
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setter
position → Vec2
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Vec2
no setter
width → int
no setter
x → int
no setter
y → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited