RoomConstraint class

Data model for constraining the dimensions of Rooms

Inheritance

Constructors

RoomConstraint(int min, int max)
const

Properties

first → int
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iterator → Iterator
Get the tuple elements as an Iterator
no setterinherited
max → int
no setter
min → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
finalinherited
sequence → List
Get the tuple elements as an ordered List
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited