TileMap<T extends TileBase> class

2D array of tiles, most often used for representing a level (see LevelTile) or world map.

Inheritance

Constructors

TileMap(int width, int height, T initialValue)
Create a TileMap with the given width and height, in tiles, filled with the given initialValue.

Properties

bounds → Rect
The bounds of the map as a Rect
no setter
first → T
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the map in tiles
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<T>
Iterate through all tiles in row-major order
no setteroverride
last → T
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → T
Checks that this iterable has only one element, and returns that element.
no setterinherited
totalTiles → int
Total number of tiles in the map
no setter
width → int
The width of the map in tiles
no setter

Methods

any(bool test(T element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
countClosedNeighbors(int x, int y) → int
The number of cardinal neighbors of the tile at column x row y that are closed (not open)
countNeighbors(int x, int y) → int
The number of cardinal neighbors of the tile at column x row y
countOpenNeighbors(int x, int y) → int
The number of cardinal neighbors of the tile at column x row y that are open
elementAt(int index) → T
Returns the indexth element.
inherited
every(bool test(T element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(T element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(T element), {T orElse()?}) → T
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<T> other) → Iterable<T>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(T element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
get(int x, int y) → T
Get the tile at column x row y
isOpen(int x, int y) → bool
true if the tile at column x row y is a valid position and is open
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(T element), {T orElse()?}) → T
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(T e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
neighbors(int x, int y) → List<T>
Get all of the cardinal neighbors of the tile at column x row y.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(T combine(T value, T element)) → T
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
set(int x, int y, T value) → T
Set the tile at column x row y to value. Returns the old tile at that position.
singleWhere(bool test(T element), {T orElse()?}) → T
The single element that satisfies test.
inherited
skip(int count) → Iterable<T>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(T element)) → Iterable<T>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<T>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(T element)) → Iterable<T>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<T>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<T>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(T element)) → Iterable<T>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Vec2 position) → T
Get the tile at the given position
operator []=(Vec2 position, T value) → void
Set the tile at position to value