TupleBase class abstract

Implementers

Constructors

TupleBase()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iterator → Iterator
Get the tuple elements as an Iterator
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → List
Get the tuple elements as an ordered List
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited