Char class

Immutable character intended to be written to a Terminal

Constructors

Char(int charCode, [Color? foreground, Color? background])
const
Char.create(Object charOrCharCode, [Color? foreground, Color? background])
Creates a new Char for the given charOrCharCode (which must be an int or non-empty String) using the optional foreground and background Colors.
factory

Properties

background → Color
final
charCode → int
final
foreground → Color
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

clear → const Char
The empty character (represented by a space) using the default background color Color.black
nill → const Char
The null character; useful as an initial state