Color class

Basic set of colors and color utilities

Copyright (c) 2014 Robert Nystrom. See https://github.com/munificent/malison

Constructors

Color(int r, int g, int b)
const

Properties

b → int
final
cssColor → String
no setter
g → int
final
hashCode → int
The hash code for this object.
no setteroverride
r → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Color other, [double? fractionOther]) → Color
blend(Color other, double fractionOther) → Color
blendPercent(Color other, int percentOther) → Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

aqua → const Color
black → const Color
blue → const Color
brown → const Color
darkAqua → const Color
darkBlue → const Color
darkBrown → const Color
darkGold → const Color
darkGray → const Color
darkGreen → const Color
darkOrange → const Color
darkPurple → const Color
darkRed → const Color
darkYellow → const Color
gold → const Color
gray → const Color
green → const Color
lightAqua → const Color
lightBlue → const Color
lightBrown → const Color
lightGold → const Color
lightGray → const Color
lightGreen → const Color
lightOrange → const Color
lightPurple → const Color
lightRed → const Color
lightYellow → const Color
orange → const Color
purple → const Color
red → const Color
white → const Color
yellow → const Color